/*
 *  Emu20k1 registers
 *
 *  Copyright(c) 2008 Takashi Iwai <tiwai@suse.de>
 *
 *  Based on sbxfi driver of OSS v4.0 OSS version:
 *    Copyright (C) 4Front Technologies 1996-2008.
 *    Copyright (C) Creative Technology, Ltd., 2007. All rights reserved.
 *
 *  This this source file is released under GPL v2 license (no other versions).
 *  See the COPYING file included in the main directory of this source
 * distribution for the license terms and conditions.
 */

#ifndef __SOUND_EMU20K1_REGS_H
#define __SOUND_EMU20K1_REGS_H

/* PCI function I/O map */
#define IO_PTR		0x00	/* 20k1 Pointer register */
#define IO_DATA		0x04	/* 20k1 Data register */
#define IO_IPR		0x08	/* Global interrupt pending register */
				/* See IPR at 0x1C6010 for details	*/
#define IO_WC		0x0c	/* Wall Clock register */
				/* See WC at 0x1C6000 for details	*/
#define IO_PCI_CONF_ADDR	0x10	/* PCI Configuration Address Register */
# define IO_PCI_BE_MASK		0xf000		/* Byte lanes enable */
# define IO_PCI_FUNC_MASK	0x0700		/* PCI function number */
# define IO_PCI_REG_MASK	0x00fc		/* PCI register number */
# define IO_PCI_ZERO_MASK	0x0002		/* Hardwired to 00 */
#define IO_PCI_CONF_DATA	0x14	/* PCI Configuration Data Register */
# define IO_PCI_DBL3_MASK	0xff000000	/* Byte 3 of read data */
# define IO_PCI_DBL2_MASK	0x00ff0000	/* Byte 2 of read data */
# define IO_PCI_DBL1_MASK	0x0000ff00	/* Byte 1 of read data */
# define IO_PCI_DBL0_MASK	0x000000ff	/* Byte 0 of read data */

/* 20k1 registers */

/* Summary of 20k1 register groups.
 * Base Address Block Name
 * 0x000000     DSP
 * 0x110000     Tank
 * 0x130000     Transport
 * 0x140000     Mixer
 * 0x1b0000     SRC
 * 0x1c0000     Filter
 * 0x1c5000     Digital Audio I/O
 * 0x1c6000     Miscellaneous
 * 0x1c7000     SDRAM I/F
 */

#define	DSP_XRAM 			0x000000
#define	DSP_XRAM_END 			0x013ffc
#define	DSP_AXRAM 			0x020000
#define	DSP_AXRAM_END 			0x023ffc
#define	DSP_YRAM 			0x040000
#define	DSP_YRAM_END 			0x04fffc
#define	DSP_AYRAM 			0x020000
#define	DSP_AYRAM_END 			0x063ffc
#define	DSP_MICRO 			0x080000
#define	DSP_MICRO_END 			0x0b3ffc
/* 0x0b4000 - 0x09fffc  Unused */

#define	DSP0_IO 			0x100000
#define	DSP0_IO_END 			0x101ffc
#define	DSP0_AUDIORING_IN		0x100000
#define	DSP0_AUDIORING_IN_END		0x1003fc
#define	DSP0_AUDIORING_OUT 		0x100400
#define	DSP0_AUDIORING_OUT_END		0x1007fc
#define	DSP0_AUDIORING_PARM		0x100800
#define	DSP0_AUDIORING_PARM_END		0x100bfc
#define	DSP0_LOCAL_HWREG 		0x100C00
#define	DSP0_LOCAL_HWREG_END	 	0x100c3c
#define	DSP0_XYRAMAGINDEX 		0x100c40
#define	DSP0_XYRAMAGINDEX_END	 	0x100c5c
#define	DSP0_XYRAMAGMOD 		0x100c60
#define	DSP0_XYRAMAGMOD_END 		0x100c7c
#define	DSP0_INT_CONTL_VEC 		0x100c80
#define	DSP0_INT_CONTL_VEC_END	 	0x100cd8
#define	GLOBAL_INT_CONTL 		0x100d1c
#define	GLOBAL_INT_CONTL_END		0x100d3c
#define	DSP0_HOST_INTFPORTADDRCONT	0x100d40
#define	DSP0_HOST_INTFPORTDATA		0x100d44
#define	DSP0_TIME0_PERENB		0x100d60
#define	DSP0_TIME0_COUNTER		0x100d64
#define	DSP0_TIME1_PERENB		0x100d68
#define	DSP0_TIME1_COUNTER		0x100d6c
#define	DSP0_TIME2_PERENB		0x100d70
#define	DSP0_TIME2_COUNTER		0x100d74
#define	DSP0_TIME3_PERENB		0x100d78
#define	DSP0_TIME3_COUNTER		0x100d7c
#define	DSP0_XRAM_INDOPERREFNOUP	0x100d80
#define	DSP0_XRAM_INDOPERREFNOUP_END	0x100d9c
#define	DSP0_XRAM_INDOPERREFUP		0x100da0
#define	DSP0_XRAM_INDOPERREFUP_END	0x100dbc
#define	DSP0_YRAM_INDOPERREFNOUP	0x100dc0
#define	DSP0_YRAM_INDOPERREFNOUP_END	0x100ddc
#define	DSP0_YRAM_INDOPERREFUP		0x100de0
#define	DSP0_YRAM_INDOPERREFUP_END	0x100dfc
#define	DSP0_CONDCODE			0x100e00
#define	DSP0_STACKFLAG			0x100e04
#define	DSP0_PROGCOUNT_STACKPT		0x100e08
#define	DSP0_PROGCOUNT_STACKDATA 	0x100e0c
#define	DSP0_CURLOOPADDR 		0x100e10
#define	DSP0_CURLOOPCOUNT 		0x100e14
#define	DSP0_TOPLOOPCOUNTSTACK 		0x100e18
#define	DSP0_TOPLOOPADDRSTACK 		0x100e1c
#define	DSP0_LOOPSTACKPTR 		0x100e20
#define	DSP0_STASSTACKDATA 		0x100e24
#define	DSP0_STASSTACKPTR 		0x100e28
#define	DSP0_PROGCOUNT			0x100e2c
#define	GLOBAL_DSP_DEBG			0x100e30
#define	GLOBAL_DSP_BREAKPOINT		0x100e34
#define	DSP0_XYRAMBASE	 		0x100ea0
#define	DSP0_XYRAMBASE_END 		0x100ebc
#define	DSP0_XYRAMLENGTH 		0x100ec0
#define	DSP0_XYRAMLENGTH_END 		0x100edc
#define	DSP0_SEMAPHORE			0x100ee0
#define	DSP0_INTCONTMASK		0x100ee4
#define	DSP0_INTCONTPEND		0x100ee8
#define	DSP0_INTCONTSERVINT		0x100eec
#define	GLOBAL_DSP_INTCONTEXTINTMOD	0x100ef0
#define	DSP0_GPIO			0x100efc
#define	DSP0_DMADSPBASEADDR		0x100f00
#define	DSP0_DMADSPBASEADDR_END		0x100f1c
#define	DSP0_DMAHOSTBASEADDR		0x100f20
#define	DSP0_DMAHOSTBASEADDR_END	0x100f3c
#define	DSP0_DMADSPCURADDR		0x100f40
#define	DSP0_DMADSPCURADDR_END		0x100f5c
#define	DSP0_DMAHOSTCURADDR		0x100f60
#define	DSP0_DMAHOSTCURADDR_END		0x100f7c
#define	DSP0_DMATANXCOUNT		0x100f80
#define	DSP0_DMATANXCOUNT_END		0x100f9c
#define	DSP0_DMATIMEBUG			0x100fa0
#define	DSP0_DMATIMEBUG_END		0x100fac
#define	DSP0_DMACNTLMODF		0x100fc0
#define	DSP0_DMACNTLMODF_END		0x100fdc
#define DSP0_DMA_GLOBAL_STATS		0x100fe0	/* 0x100fec? */

#define DSP0_XGPRAM	 		0x101000
#define DSP0_XGPRAM_END 		0x1017fc
#define DSP0_YGPRAM	 		0x101800
#define	DSP0_YGPRAM_END 		0x101ffc

/* DSP0 specific started at 0x100000
 * DSP1 specific starts  at 0x102000
 * DSP2 specific starts  at 0x104000
 * DSP3 specific starts  at 0x106000
 */

/* end of DSP reg definitions */

/* DSP Audio Ring Input Mapper */
#define	DSP_AIMAP		0x108000
#define	DSP_AIMAP_END		0x1083fc
/* DSP Parameter Ring Input Mapper */
#define	DSP_PIMAP		0x108400
#define DSP_PIMAP_END		0x1087fc
/* DSP Parameter Ring Output Mapper */
#define DSP_POMAP		0x108800
#define DSP_POMAP_END		0x108bfc
/* DSP Parameter Ring Output Control */
#define DSP_POCTL		0x108c00

/* Start of TANK definitions */
/* Tank control */
#define TANK_CTL		0x110000
#define TANK_CTL_END		0x110ffc
/* Tank Clear Count */
#define	TANK_CC			0x111000
#define TANK_CC_END		0x111ffc
/* Tank Audio Ring Input Mapper */
#define TANK_IMAP		0x112000
#define TANK_IMAP_END		0x112ffc
#define	TANK_DELAYCTR16		0x113000
#define	TANK_PARTITIONBASE16	0x113004
#define	TANK_BUFSIZE16		0x113008
#define	TANK_DELAYCTR32		0x11300c
#define	TANK_PARTITIONBASE32	0x113010
#define	TANK_BUFSIZE32		0x113014
#define	TANK_INT_DELAYCTR16	0x113018
#define	TANK_INT_BUFSIZE16	0x11301c
#define	TANK_INT_DELAYCTR32	0x113020
#define	TANK_INT_BUFSIZE32	0x113024
#define	TANK_INT_START_CHAN	0x113028
#define	TANK_SQUELCH_CTL	0x11302c

#define	TANK_SEC_CACHE_CTL	0x114000
#define	TANK_SEC_CACHE_CTL_END	0x11403c
#define	TANK_SEC_CACHE_ADDR	0x114100
#define	TANK_SEC_CACHE_ADDR_END	0x11413c
#define	TANK_SEC_CACHE_DATA	0x114800
#define	TANK_SEC_CACHE_DATA_END	0x1149fc
#define	TANK_PRI_CACHE_DATA	0x120000
#define	TANK_PRI_CACHE_DATA_END	0x12fffc
/* End of TANK definitions */

/* Start of TRANSPORT definitions */
#define	TRANS_MAP_LOG_ADDR_A	0x130000
#define	TRANS_MAP_PHY_ADDR_HI_A	0x130004
#define	TRANS_MAP_PHY_ADDR_LO_A	0x130008
#define	TRANS_MAP_LOG_ADDR_B	0x130010
#define	TRANS_MAP_PHY_ADDR_HI_B	0x130014
#define	TRANS_MAP_PHY_ADDR_LO_B	0x130018
/* 0x130020 - 0x13A2FC  repeating A and B (location 0) above
 * 			until 0x1303, each one taking 0x20 bytes.
 */

#define	TRANS_TLB_PHY_ADDR_HI_0		0x13b000
#define	TRANS_TLB_PHY_ADDR_LO_0		0x13b004
/* 0x13B008 - 0x13B07C  repeating HI and LO (location 0) above
 * 			until 0x15, each one taking 0x8 bytes.
 */

#define	TRANS_QUEUE_ADDR_0		0x13b100
/* 0x13B104 - 0x13B13C  repeating (location 0) above
 * 			until 0xF, each one taking 0x4 bytes.
 */
#define	TRANS_QUEUE_TIMER_PRIORITY	0x13b200
/* 0x13B204 - 0x13B23C  repeating (location 0) above
 * 			until 0xF, each one taking 0x4 bytes.
 */
#define	TRANS_QUEUE_PARAM		0x13b300
/* 0x13B304 - 0x13B33C  repeating (location 0) above
 * 			until 0xF, each one taking 0x4 bytes.
 */
#define	TRANS_QUEUE_COUNT		0x13b400
#define	TRANS_CTL			0x13b404
#define	TRANS_INT_STAT			0x13b408
#define	TRANS_CUR_TRANS_STAT		0x13b40c

/* Audio mixer */
#define	AUDIO_MIXER_OPCODES		0x140000
#define	AMOP_START(n)			(AUDIO_MIXER_OPCODES + (8 * (n)))
/* 0x140008 - 0x147FFC  repeating (location 0) above
 * 			until 0x0FFF, each one taking 0x8 bytes.
 */
#define	PARAM_MIXER_OPCODES		0x148000
/* 0x148008 - 0x14FFFC  repeating (location 0) above
 * 			until 0x0FFF, each one taking 0x8 bytes.
 */
#define	PARAM_CURR_VALUE		0x150000
/* 0x150004 - 0x153FFC  repeating (location 0) above
 * 			until 0x0FFF, each one taking 0x4 bytes.
 */
#define	PARAM_TARGET			0x154000
/* 0x154004 - 0x157FFC  repeating (location 0) above
 * 			until 0x0FFF, each one taking 0x4 bytes.
 */
#define	PARAM_SHAPE_RATE		0x158000
/* 0x158004 - 0x15BFFC  repeating (location 0) above
 * 			until 0x0FFF, each one taking 0x4 bytes.
 */
#define	PARAM_FIFO_STAT_4SEG		0x160000
/* 0x160004 - 0x160BFC  repeating (location 0) above
 * 			until 0x0299, each one taking 0x4 bytes.
 */
#define	PARAM_FIFO_STAT_2SEG		0x160c00
/* 0x160C04 - 0x1617FC  repeating (location 0) above
 * 			until 0x0299, each one taking 0x4 bytes.
 */
#define	PARAM_FIFO_TARGET_4SEG		0x164000
/* 0x164004 - 0x164BFC  repeating (location 0) above
 * 			until 0x0299, each one taking 0x4 bytes.
 */
#define	PARAM_FIFO_TARGET_2SEG		0x164c00
/* 0x164C04 - 0x1657FC  repeating (location 0) above
 * 			until 0x0299, each one taking 0x4 bytes.
 */
#define	PARAM_FIFO_SHAPE_RATE_4SEG	0x168000
/* 0x168004 - 0x168BFC  repeating (location 0) above
 * 			until 0x0299, each one taking 0x4 bytes.
 */
#define	PARAM_FIFO_SHAPE_RATE_2SEG	0x168c00
/* 0x168C04 - 0x1697FC  repeating (location 0) above
 * 			until 0x0299, each one taking 0x4 bytes.
 */
#define	PARAM_CUR_VAL_4SEG		0x16c000
/* 0x16C004 - 0x16CBFC  repeating (location 0) above
 * 			until 0x0299, each one taking 0x4 bytes.
 */
#define	PARAM_CUR_VAL_2SEG		0x16cc00
/* 0x16CC04 - 0x16D7FC  repeating (location 0) above
 * 			until 0x0299, each one taking 0x4 bytes.
 */
#define	PARAM_TARGET_4SEG		0x170000
/* 0x170004 - 0x172FFC  repeating (location 0) above
 * 			until 0x0299, each one taking 0x4 bytes.
 */
#define	PARAM_TARGET_2SEG		0x173000
/* 0x173004 - 0x1747FC  repeating (location 0) above
 * 			until 0x0299, each one taking 0x4 bytes.
 */
#define	PARAM_SHAPE_RATE_4SEG		0x180000
/* 0x180004 - 0x182FFC  repeating (location 0) above
 * 			until 0x0299, each one taking 0x4 bytes.
 */
#define	PARAM_SHAPE_RATE_2SEG		0x183000
/* 0x183004 - 0x1847FC  repeating (location 0) above
 * 			until 0x0299, each one taking 0x4 bytes.
 */
#define	PARAM_RING_LO			0x190000
/* 0x190004 - 0x193FFC  repeating (location 0) above
 * 			until 0x0999, each one taking 0x4 bytes.
 */
#define	PARAM_RING_HI			0x194000
/* 0x194004 - 0x197FFC  repeating (location 0) above
 * 			until 0x0999, each one taking 0x4 bytes.
 */
#define	PARAM_RING_LO_HI		0x198000
#define	PRING_LO_HI_START(n)		(PARAM_RING_LO_HI + (4 * (n)))
/* 0x198004 - 0x19BFFC  repeating (location 0) above
 * 			until 0x0999, each one taking 0x4 bytes.
 */
#define	PARAM_FIFO_INTERRUPT		0x1a0000

/* End of TRANSPORT PARAMs */

/* Start of SRC for Channel 0 */
/* 0x1B00xx + (0x100 * channel) */
#define SRC_CTL				0x1b0000
#define	SRCCTL(n)			(SRC_CTL + ((n) * 0x100))
# define SRCCTL_BYPASS		(1<<20)	/* bypass SRC */
# define SRCCTL_ILSZ		(15<<16) /* interleave size */
# define SRCCTL_ILSZ_SHIFT	16
/* indicates number of contiguous channels that are part of
 * an interleaved group.
 * Only needs to be tagged in the first channel of the group
 */
# define SRCCTL_IE		(1<<15) /* interrupt enable: interrupt after
					 * the last sample in the loop
					 */
# define SRCCTL_STOP_ON_LOOP	(1<<14)	/* stop on loop: stop after last sample
					 * in the loop
					 */
# define SRCCTL_VO		(1<<13)	/* variable output rate,
					 * fixed input rate
					 */
# define SRCCTL_PITCH_ROM	(3<<11)	/* pitch ROM select */
#  define SRCCTL_PITCH_HIGH	(0<<11)	/* 0 to 8.0: very high quality */
#  define SRCCTL_PITCH_EXT_HIGH	(1<<11)	/* 0.26 to 1.72: extermely high qual.*/
#  define SRCCTL_PITCH_88kHZ	(2<<11)	/* 1.8375: 88.2kHz 48kHz */
#  define SRCCTL_PITCH_96KHZ	(3<<11) /* 2.0: 96kHz 48kHz */
# define SRCCTL_PITCH_MASTER	(1<<10) /* pitch master of following channels:
					 * used to phase lock neighboring
					 * channels together
					 */
# define SRCCTL_WR		(1<<9)  /* write cache to memory:
					 * takes samples only from the ring,
					 * and not from the host
					 */
# define SRCCTL_FORMAT		(7<<6)	/* sample format */
#  define SRCCTL_FMT_U8		(0<<6)	/* 8-bit unsigned */
#  define SRCCTL_FMT_S16		(1<<6)	/* 16-bit signed */
#  define SRCCTL_FMT_S24_3		(2<<6)	/* 24-bit packed on 3 bytes */
#  define SRCCTL_FMT_S32		(3<<6)	/* 32-bit */
#  define SRCCTL_FMT_FLOAT		(4<<6)	/* 32-bit float */
# define SRCCTL_REF_RATE	(3<<4)	/* reference sample rate */
#  define SRCCTL_REF_48K		(0<<4)	/* using 1 channel */
#  define SRCCTL_REF_96K		(1<<4)	/* using 2 channels */
#  define SRCCTL_REF_192K		(2<<4)	/* using 4 channels */
#  define SRCCTL_REF_384K		(3<<4)	/* using 8 channels */
/* Note: 44.1kHz is possible, but is more complex because it uses a method
 * whereby the channel ring marks each sample in the channel ring as valid
 * or not, so to get 44.1kHz, some samples are simply tagged invalid. The
 * "channel ring" is not the ring buffer that is used to get sound samples
 * to the card. The "channel ring" is used to pass samples between
 * different processing modules on the card. One of these processing
 * modules is the SRC, another is the INs/OUTs, another is the hardware
 * mixer, and yet another is the DSP.
 */
# define SRCCTL_BUS_MASTER	(1<<3)	/* bus master enable */
# define SRCCTL_STATE		(7<<0)	/* SRC state */
#  define SRCCTL_STATE_OFF		(0<<0)
#  define SRCCTL_STATE_RESERVED		(1<<0)
#  define SRCCTL_STATE_TAIL		(2<<0)
#  define SRCCTL_STATE_STOPPING		(3<<0)
#  define SRCCTL_STATE_INIT		(4<<0)
#  define SRCCTL_STATE_RUN		(5<<0)
#  define SRCCTL_STATE_INIT_AUTO_LOAD	(6<<0)
#  define SRCCTL_STATE_RUN_AUTO_LOAD	(7<<0)
#define	SRC_CACHE_CTL			0x1b0004
#define	SRCCCR(n)			(SRC_CACHE_CTL + ((n) * 0x100))
#define	SRC_INPUT_MAPPER		0x1b0008
#define	SRCIMAP(n)			(SRC_INPUT_MAPPER + ((n) * 0x100))
#define	SRC_ODD_CACHE			0x1b000c
#define	SRC_CUR_ADDR			0x1b0010
#define	SRCCA(n)			(SRC_CUR_ADDR + ((n) * 0x100))
#define	SRC_CUR_FRAC			0x1b0014
#define	SRCCF(n)			(SRC_CUR_FRAC + ((n) * 0x100))
#define	SRC_START_ADDR			0x1b0018
#define	SRCSA(n)			(SRC_START_ADDR + ((n) * 0x100))
#define	SRC_LOOP_ADDR			0x1b001c
#define	SRCLA(n)			(SRC_LOOP_ADDR + ((n) * 0x100))
#define	SRC_CTL_SYNC_WRITE		0x1b0020

#define	SRC_AUTO_LOAD_BASE_ADDR		0x1b002c
#define	SRC_MASTER_CTL			0x1b012c
#define	SRC_CACHE_ERR			0x1b022c
#define	SRC_INIT_TIME_BUDGET		0x1b032c
#define	SRC_INT_PENDING_MAP		0x1b082c
#define	SRC_INT_PENDING_0		0x1b102c
#define	SRC_INT_PENDING_1		0x1b112c
#define	SRC_INT_PENDING_2		0x1B122C
#define	SRC_INT_PENDING_3		0x1B132C
#define	SRC_INT_PENDING_4		0x1B142C
#define	SRC_INT_PENDING_5		0x1B152C
#define	SRC_INT_PENDING_6		0x1B162C
#define	SRC_INT_PENDING_7		0x1B172C
#define	SRCIP(n)			(SRC_INT_PENDING_0 + ((n) * 0x100))
/* 0x1B17xx - 0x1B1Fxx Unused */
#define	SRC_ENABLE_STAT			0x1B202C
#define	SRC_ENABLE_LO			0x1B212C
#define	SRC_ENABLE_HI			0x1B222C
#define	SRC_ENABLE_SYNCHRONOUS		0x1B232C
#define	SRC_ENABLE_0			0x1B282C
#define	SRC_ENABLE_1			0x1B292C
#define	SRC_ENABLE_2			0x1B2A2C
#define	SRC_ENABLE_3			0x1B2B2C
#define	SRC_ENABLE_4			0x1B2C2C
#define	SRC_ENABLE_5			0x1B2D2C
#define	SRC_ENABLE_6			0x1B2E2C
#define	SRC_ENABLE_7			0x1B2F2C
#define	SRC_ENABLE_SYNCHRONOUS_0	0x1B302C
#define	SRC_ENABLE_SYNCHRONOUS_1	0x1B312C
#define	SRC_ENABLE_SYNCHRONOUS_2	0x1B322C
#define	SRC_ENABLE_SYNCHRONOUS_3	0x1B332C
#define	SRC_ENABLE_SYNCHRONOUS_4	0x1B342C
#define	SRC_ENABLE_SYNCHRONOUS_5	0x1B352C
#define	SRC_ENABLE_SYNCHRONOUS_6	0x1B362C
#define	SRC_ENABLE_SYNCHRONOUS_7	0x1B372C
#define	SRC_DOWN_SAMPLER_STAGE_0_Z_0	0x1B0030
#define	SRC_DOWN_SAMPLER_STAGE_0_Z_1	0x1B0034
#define	SRC_DOWN_SAMPLER_STAGE_0_Z_2	0x1B0038
#define	SRC_DOWN_SAMPLER_STAGE_0_Z_3	0x1B003C
#define	SRC_DOWN_SAMPLER_STAGE_1_Z_0	0x1B0040
#define	SRC_DOWN_SAMPLER_STAGE_1_Z_1	0x1B0044
#define	SRC_DOWN_SAMPLER_STAGE_1_Z_2	0x1B0048
#define	SRC_DOWN_SAMPLER_STAGE_1_Z_3	0x1B004C
#define	SRC_DOWN_SAMPLER_STAGE_1_Z_4	0x1B0050
#define	SRC_DOWN_SAMPLER_STAGE_1_Z_5	0x1B0054
#define	SRC_DOWN_SAMPLER_STAGE_1_Z_6	0x1B0058
#define	SRC_DOWN_SAMPLER_STAGE_1_Z_7	0x1B005C
#define	SRC_UP_SAMPLE_Z_0		0x1B0060
#define	SRC_UP_SAMPLE_Z_1		0x1B0064
#define	SRC_UP_SAMPLE_Z_2		0x1B0068
#define	SRC_UP_SAMPLE_Z_3		0x1B006C
#define	SRC_UP_SAMPLE_Z_4		0x1B0070
#define	SRC_UP_SAMPLE_Z_5		0x1B0074
#define	SRC_UP_SAMPLE_Z_6		0x1B0078
#define	SRC_UP_SAMPLE_Z_7		0x1B007C
#define	SRC_CACHE_DATA_0		0x1B0080
#define	SRC_CACHE_DATA_1		0x1B0084
#define	SRC_CACHE_DATA_2		0x1B0088
#define	SRC_CACHE_DATA_3		0x1B008C
#define	SRC_CACHE_DATA_4		0x1B0090
#define	SRC_CACHE_DATA_5		0x1B0094
#define	SRC_CACHE_DATA_6		0x1B0098
#define	SRC_CACHE_DATA_7		0x1B009C
#define	SRC_CACHE_DATA_8		0x1B00A0
#define	SRC_CACHE_DATA_9		0x1B00A4
#define	SRC_CACHE_DATA_A		0x1B00A8
#define	SRC_CACHE_DATA_B		0x1B00AC
#define	SRC_CACHE_DATA_C		0x1B00B0
#define	SRC_CACHE_DATA_D		0x1B00B4
#define	SRC_CACHE_DATA_E		0x1B00B8
#define	SRC_CACHE_DATA_F		0x1B00BC
#define	SRC_CACHE_DATA_10		0x1B00C0
#define	SRC_CACHE_DATA_11		0x1B00C4
#define	SRC_CACHE_DATA_12		0x1B00C8
#define	SRC_CACHE_DATA_13		0x1B00CC
#define	SRC_CACHE_DATA_14		0x1B00D0
#define	SRC_CACHE_DATA_15		0x1B00D4
#define	SRC_CACHE_DATA_16		0x1B00D8
#define	SRC_CACHE_DATA_17		0x1B00DC
#define	SRC_CACHE_DATA_18		0x1B00E0
#define	SRC_CACHE_DATA_19		0x1B00E4
#define	SRC_CACHE_DATA_1A		0x1B00E8
#define	SRC_CACHE_DATA_1B		0x1B00EC
#define	SRC_CACHE_DATA_1C		0x1B00F0
#define	SRC_CACHE_DATA_1D		0x1B00F4
#define	SRC_CACHE_DATA_1E		0x1B00F8
#define	SRC_CACHE_DATA_1F		0x1B00FC
/* SRC control blocks (channels 1 - 255) */
/* Ends at 0x1BFFFC */

#define	FILT_OPCODE			0x1C0000
/* 0x1C0004 - 0x1C05FC  repeating (location 0) above
 * 			until 0x17F, each one taking 0x4 bytes.
 */
/* 0x1C0600  0x1C07FC Unused */
#define	FILT_AUDIO_RING_INPUT_MAPPER	0x1C0800
/* 0x1C0804 - 0x1C0DFC  repeating (location 0) above
 * 			until 0x17F, each one taking 0x4 bytes.
 */
#define	FILT_Z1				0x1C1000
/* 0x1C1004 - 0x1C15FC  repeating (location 0) above
 * 			until 0x17F, each one taking 0x4 bytes.
 */
#define	FILT_Z2				0x1C1800
/* 0x1C1804 - 0x1C1DFC  repeating (location 0) above
 * 			until 0x17F, each one taking 0x4 bytes.
 */
#define	DAIO_AUDIO_RING_INPUT_MAPPER	0x1c5000
#define	DAOIMAP_START(n)		(0x1c5000 + (4 * (n)))
/* 0x1C5004 - 0x1C5124  repeating (location 0) above
 * 			until 0x4A, each one taking 0x4 bytes.
 */
#define	AC97D		0x1C5400
#define	AC97A		0x1C5404
#define	AC97CTL		0x1C5408
#define	I2SCTL		0x1C5420

#define	SPDIF_OUT_STATUS_A	0x1C5440
#define	SPDIF_OUT_STATUS_B	0x1C5444
#define	SPDIF_OUT_STATUS_C	0x1C5448
#define	SPDIF_OUT_STATUS_D	0x1C544C

#define	SPDIF_IN_STATUS_A	0x1C5450
#define	SPDIF_IN_STATUS_B	0x1C5454
#define	SPDIF_IN_STATUS_C	0x1C5458
#define	SPDIF_IN_STATUS_D	0x1C545C

#define	SPDIF_FULL_CHANNEL_STATUS_CTL	0x1C5460

#define	SPDIF_FULL_CHANNEL_STATUS_0	0x1C5468
#define	SPDIF_FULL_CHANNEL_STATUS_1	0x1C546C
#define	SPDIF_FULL_CHANNEL_STATUS_2	0x1C5470
#define	SPDIF_FULL_CHANNEL_STATUS_3	0x1C5474
#define	SPDIF_FULL_CHANNEL_STATUS_4	0x1C5478
#define	SPDIF_FULL_CHANNEL_STATUS_5	0x1C547C

#define	SPDIF_OUTPUT_CTL		0x1C5480
#define	SPDIF_INPUT_CTL			0x1C5484
#define	SPDIF_INPUT_STATUS		0x1C5488
#define	SPDIF_INT_PENDING		0x1C548C
#define	SPDIF_INT_ENABLE		0x1C5490
#define	SPDIF_USER_BITS_TRANSMIT_CTL_AB	0x1C5494
#define	SPDIF_USER_BITS_TRANSMIT_CTL_CD	0x1C5498

#define	SPDIF_SAMPLE_RATE_TRACKER_CTL_A	0x1C54D0
#define	SPDIF_SAMPLE_RATE_TRACKER_CTL_B	0x1C54D4
#define	SPDIF_SAMPLE_RATE_TRACKER_CTL_C	0x1C54D8
#define	SPDIF_SAMPLE_RATE_TRACKER_CTL_D	0x1C54DC

#define	SPDIF_SAMPLE_RATE_TRACKER_CTL_A	0x1C54D0
#define	SPDIF_SAMPLE_RATE_TRACKER_CTL_B	0x1C54D4
#define	SPDIF_SAMPLE_RATE_TRACKER_CTL_C	0x1C54D8
#define	SPDIF_SAMPLE_RATE_TRACKER_CTL_D	0x1C54DC

#define	I2S_SAMPLE_RATE_TRACKER_STATUS	0x1C54E0
#define	I2S_SAMPLE_RATE_TRACKER_CTL	0x1C54F0

#define WALL_CLOCK		0x1C6000	/* Wall Clock register */
/* 20-bit counter indicating sample periods elapsed since
 * Enable AR Channel is asserted (see the Global Control
 * register). The maximum value this register can hold is
 * 1048575. This register will wrap about every 22 seconds
 * in 48 kHz Sample Rate mode.
 */
#define WC_SPLC_MASK		0xFFFFF000
/* CHID is a counter that runs at the internal clock rate of
 * the chip. This identifies the channel currently being
 * processed at the Mixer. The channel ID present at other
 * blocks will differ from this value by an amount that
 * depends on the position of the block on the audio ring.
 * Each block inserts a 2-clock delay on the audio ring. For
 * example, 2 blocks down from the mixer, the channel ID is
 * equal to CHID-4.
 * The various Turbo modes will cause this value to wrap at
 * different values. In 150MHz mode, this value wraps at
 * 0xBFF. In 175MHz mode, this value wraps at 0xDFF. In
 * 200MHz mode, this value wraps at 0xFFF.
 */
#define WC_CHID_MASK		0x00000FFF

#define	TIMR			0x1c6004
# define	TIMR_IE		(1<<15)
# define	TIMR_IP		(1<<14)

/* Global interrupt pending reg */
/* Clear pending interrupts by writing a 1 to the relevant bits and
 * zero to the other bits
 */
#define	GLOBAL_INT_PENDING		0x1c6010
/* Indicates an interrupt is pending from the PLL,
 * indicating that the PLL has detected the input clock
 * is out of range. This bit is read-only and must be
 * cleared by writing to the PLL control register.
 */
# define		PLL_INT			(1<<10)
/* Indicates an interrupt is pending from a forced
 * interrupt. This bit is read-write and allows software to
 * generate a hardware interrupt.
 */
# define		FI_INT			(1<<9)
/* Indicates an interrupt is pending from the interval
 * timer. This bit is cleared by getting its local interrupt
 * signal to be 0.
 */
# define		IT_INT			(1<<8)
/* Indicates an interrupt is pending from a PCI bus
 * error such as a PCI Master Abort or System Error.
 * The error source can be further defined using the
 * PCI status configuration register. This bit is cleared
 * by writing a 1 to it.
 */
# define		PCI_INT			(1<<7)
/* Indicates an interrupt is pending from one or more
 * UART Transmitters or Receivers. This bit is cleared
 * by getting its local interrupt signal to be 0.
 */
# define		URT_INT			(1<<6)
/* Indicates an interrupt is pending from one or more
 * General Purpose Input pins. This bit is cleared by
 * getting its local interrupt signal to be 0.
 */
# define		GPI_INT			(1<<5)
/* Indicates an interrupt is pending from one or more
 * Mixer Parameter Segment FIFO channels. This bit is
 * cleared by writing a 1 to it.
 */
# define		MIX_INT			(1<<4)
/* Indicates an interrupt is pending from the digital
 * audio inputs: one or more Sample Rate Trackers or
 * S/PDIF Receivers. This bit is cleared by getting its
 * local interrupt signal to be 0.
 */
# define		DAI_INT			(1<<3)
/* Indicates an interrupt is pending from one or more
 * entries over the priority threshold in the transport
 * priority queue. This bit is cleared by getting its local
 * interrupt signal to be 0.
 */
# define		TP_INT			(1<<2)
/* Indicates an interrupt is pending from the DSP. This
 * bit is cleared by writing a 1 to it.
 */
# define		DSP_INT			(1<<1)
/* Indicates an interrupt is pending from one or more
 * SRC channels. This bit is cleared by getting its local
 * interrupt signal to be 0.
 */
# define		SRC_INT			(1<<0)

#define	GLOBAL_INT_ENABLE		0x1c6014
#define	DELAYED_INT_ENABLE		0x1c6018
#define	DELAYED_INT_CTL			0x1C601C
#define	GPIO			0x1C6020
#define	GPIO_CTL		0x1C6024
#define	GPI_PENDING		0x1C6028
#define	GPI_ENABLE		0x1C602C
#define	DSP_INT0_CTL		0x1C6030
#define	DSP_INT_PHASE_CORRECT	0x1C6034
#define	MIDI_UART_DATA_A	0x1C6040
#define	MIDI_UART_CMD_A		0x1C6044 /* Same reg as next */
#define	MIDI_UART_STATUS_A	0x1C6044 /* Same reg as previous */
#define	MIDI_UART_DATA_B	0x1C6048
#define	MIDI_UART_CMD_B		0x1C604C /* Same reg as next */
#define	MIDI_UART_STATUS_B	0x1C604C /* Same reg as previous */
#define	MIDI_UART_COUNTER_MAX_A	0x1C6050
#define	MIDI_UART_COUNTER_MAX_B	0x1C6054
#define	MIDI_UART_INT_PEND	0x1C6058
#define	MIDI_UART_INT_ENABLE	0x1C605C
#define	PLL_CTL			0x1C6060
#define	PLL_DEFAULT_CLK_DEV	0x1C6064
#define	GLOBAL_CTL		0x1C6070
# define	GCTL_AID	0x00100000	/* RAM Auth init done */
# define	GCTL_SE		0x00080000	/* Smart Error Status */
# define	GCTL_SD		0x00040000	/* Smart Done Status */
# define	GCTL_SR		0x00020000	/* Star Processor Reset */
# define	GCTL_SM		0x00010000	/* Smart Mode */
# define	GCTL_SDI	0x00008000	/* SDRAM Interface Immediate
						 * mode */
# define	GCTL_SDE	0x00004000	/* SDRAM Interface Enable */
# define	GCTL_MRL	0x00002000	/* Memory Read Line enable */
# define	GCTL_PR		0x00001000	/* Park Request */
# define	GCTL_ET		0x00000800	/* Transport Ring Enable */
# define	GCTL_XA		0x00000400	/* eXternal Arbiter Enable */
# define	GCTL_FBP	0x00000200	/* Filter bypass */
# define	GCTL_SBP	0x00000100	/* SRC bypass */
# define	GCTL_TBP	0x00000080	/* Tank bypass */
# define	GCTL_ABP	0x00000040	/* Audio I/O bypass */
# define	GCTL_DBP	0x00000020	/* DSP bypass */
# define	GCTL_DSP	0x00000010	/* DSP program counter enable */
# define	GCTL_BES	0x00000008	/* Big endian secondary PCI
						 * bus */
# define	GCTL_BEP	0x00000004	/* Big endian primary PCI bus
						 * or UPIF bus */
/* A 0 -> 1 transition causes the internal RAM to auto-init. */
# define	GCTL_EAI	0x00000002	/* Audio init enable */
# define	GCTL_EAC	0x00000001	/* Audio ring channel counter
						 * enable */

#define	CHIP_ID0		0x1C6080
#define	CHIP_ID1		0x1C6084
#define	CHIP_ID2		0x1C6088
#define	CHIP_ID3		0x1C608C
#define	SDRCTL			0x1C7000

/* SRC */
#define I2SA_L    0x0L
#define I2SA_R    0x1L
#define I2SB_L    0x8L
#define I2SB_R    0x9L
#define I2SC_L    0x10L
#define I2SC_R    0x11L
#define I2SD_L    0x18L
#define I2SD_R    0x19L

enum
{
	/* block 0 */
	FIL_CH_0 = 0,
	SRC_CH_0 = 0x1,
	MIXER_SUM_CH_0 = 0xc,

	/* block 1 */
	FIL_CH_1 = 0x10,
	SRC_CH_1 = 0x11,
	MIXER_SUM_CH_1 = 0x1c,
};

enum {
	DAI_CH_AC97L = 0x5e5,
	DAI_CH_AC97R = 0x7e5,
	DAI_CH_AC97MIC = 0xde5,

	/* daoi i2s out block */
	DAI_CH_I2SAL = 0x0,
	DAI_CH_I2SAR = 0x1,
	DAI_CH_I2SA1L = 0x2,
	DAI_CH_I2SA1R = 0x3,
	DAI_CH_I2SA2L = 0x4,
	DAI_CH_I2SA2R = 0x5,
	DAI_CH_I2SA3L = 0x6,
	DAI_CH_I2SA3R = 0x7,

	DAI_CH_I2SBL = 0x8,
	DAI_CH_I2SBR = 0x9,
	DAI_CH_I2SB1L = 0xa,
	DAI_CH_I2SB1R = 0xb,
	DAI_CH_I2SB2L = 0xc,
	DAI_CH_I2SB2R = 0xd,
	DAI_CH_I2SB3L = 0xe,
	DAI_CH_I2SB3R = 0xf,

	DAI_CH_I2SCL = 0x10,
	DAI_CH_I2SCR = 0x11,
	DAI_CH_I2SC1L = 0x12,
	DAI_CH_I2SC1R = 0x13,
	DAI_CH_I2SC2L = 0x14,
	DAI_CH_I2SC2R = 0x15,
	DAI_CH_I2SC3L = 0x16,
	DAI_CH_I2SC3R = 0x17,

	DAI_CH_I2SDL = 0x18,
	DAI_CH_I2SDR = 0x19,
	DAI_CH_I2SD1L = 0x1a,
	DAI_CH_I2SD1R = 0x1b,
	DAI_CH_I2SD2L = 0x1c,
	DAI_CH_I2SD2R = 0x1d,
	DAI_CH_I2SD3L = 0x1e,
	DAI_CH_I2SD3R = 0x1f,

	/* daoi spdif out */
	DAI_CH_SPDIFAL = 0x20,
	DAI_CH_SPDIFAR = 0x21,
	DAI_CH_SPDIFA1L = 0x22,
	DAI_CH_SPDIFA1R = 0x23,
	DAI_CH_SPDIFA2L = 0x24,
	DAI_CH_SPDIFA2R = 0x25,
	DAI_CH_SPDIFA3L = 0x26,
	DAI_CH_SPDIFA3R = 0x27,

	DAI_CH_SPDIFBL = 0x28,
	DAI_CH_SPDIFBR = 0x29,
	DAI_CH_SPDIFB1L = 0x2a,
	DAI_CH_SPDIFB1R = 0x2b,
	DAI_CH_SPDIFB2L = 0x2c,
	DAI_CH_SPDIFB2R = 0x2d,
	DAI_CH_SPDIFB3L = 0x2e,
	DAI_CH_SPDIFB3R = 0x2f,

	DAI_CH_SPDIFCL = 0x30,
	DAI_CH_SPDIFCR = 0x31,
	DAI_CH_SPDIFC1L = 0x32,
	DAI_CH_SPDIFC1R = 0x33,
	DAI_CH_SPDIFC2L = 0x34,
	DAI_CH_SPDIFC2R = 0x35,
	DAI_CH_SPDIFC3L = 0x36,
	DAI_CH_SPDIFC3R = 0x37,

	DAI_CH_SPDIFDL = 0x38,
	DAI_CH_SPDIFDR = 0x39,
	DAI_CH_SPDIFD1L = 0x3a,
	DAI_CH_SPDIFD1R = 0x3b,
	DAI_CH_SPDIFD2L = 0x3c,
	DAI_CH_SPDIFD2R = 0x3d,
	DAI_CH_SPDIFD3L = 0x3e,
	DAI_CH_SPDIFD3R = 0x3f,

	/* daio i2s block(in) */
	DAI_CH_I2SINA1L = 0x035,
	DAI_CH_I2SINA1R = 0x03D,
	DAI_CH_I2SINB1L = 0x0B5,
	DAI_CH_I2SINB1R = 0x0BD,
	DAI_CH_I2SINC1L = 0x135,
	DAI_CH_I2SINC1R = 0x13D,
	DAI_CH_I2SIND1L = 0x1B5,
	DAI_CH_I2SIND1R = 0x1BD,
	DAI_CH_I2SINA2L = 0x235,
	DAI_CH_I2SINA2R = 0x23D,
	DAI_CH_I2SINB2L = 0x2B5,
	DAI_CH_I2SINB2R = 0x2BD,
	DAI_CH_I2SINC2L = 0x335,
	DAI_CH_I2SINC2R = 0x33D,
	DAI_CH_I2SIND2L = 0x3B5,
	DAI_CH_I2SIND2R = 0x3BD,
	DAI_CH_I2SINA3L = 0x435,
	DAI_CH_I2SINA3R = 0x43D,
	DAI_CH_I2SINB3L = 0x4B5,
	DAI_CH_I2SINB3R = 0x4BD,
	DAI_CH_I2SINC3L = 0x535,
	DAI_CH_I2SINC3R = 0x53D,
	DAI_CH_I2SIND3L = 0x5B5,
	DAI_CH_I2SIND3R = 0x5BD,
	DAI_CH_I2SINA4L = 0x635,
	DAI_CH_I2SINA4R = 0x63D,
	DAI_CH_I2SINB4L = 0x6B5,
	DAI_CH_I2SINB4R = 0x6BD,
	DAI_CH_I2SINC4L = 0x735,
	DAI_CH_I2SINC4R = 0x73D,
	DAI_CH_I2SIND4L = 0x7B5,
	DAI_CH_I2SIND4R = 0x7BD,
	DAI_CH_I2SINA5L = 0x835,
	DAI_CH_I2SINA5R = 0x83D,
	DAI_CH_I2SINB5L = 0x8B5,
	DAI_CH_I2SINB5R = 0x8BD,
	DAI_CH_I2SINC5L = 0x935,
	DAI_CH_I2SINC5R = 0x93D,
	DAI_CH_I2SIND5L = 0x9B5,
	DAI_CH_I2SIND5R = 0x9BD,
	DAI_CH_I2SINA6L = 0xA35,
	DAI_CH_I2SINA6R = 0xA3D,
	DAI_CH_I2SINB6L = 0xAB5,
	DAI_CH_I2SINB6R = 0xABD,
	DAI_CH_I2SINC6L = 0xB35,
	DAI_CH_I2SINC6R = 0xB3D,
	DAI_CH_I2SIND6L = 0xBB5,
	DAI_CH_I2SIND6R = 0xBBD,
	DAI_CH_I2SINA7L = 0xC35,
	DAI_CH_I2SINA7R = 0xC3D,
	DAI_CH_I2SINB7L = 0xCB5,
	DAI_CH_I2SINB7R = 0xCBD,
	DAI_CH_I2SINC7L = 0xD35,
	DAI_CH_I2SINC7R = 0xD3D,
	DAI_CH_I2SIND7L = 0xDB5,
	DAI_CH_I2SIND7R = 0xDBD,
	DAI_CH_I2SINA8L = 0xE35,
	DAI_CH_I2SINA8R = 0xE3D,
	DAI_CH_I2SINB8L = 0xEB5,
	DAI_CH_I2SINB8R = 0xEBD,
	DAI_CH_I2SINC8L = 0xF35,
	DAI_CH_I2SINC8R = 0xF3D,
	DAI_CH_I2SIND8L = 0xFB5,
	DAI_CH_I2SIND8R = 0xFBD,

	/* daio cd-spidf block    */
	DAI_CH_CDSPDIFINA1L = 0x015,
	DAI_CH_CDSPDIFINA1R = 0x01D,
	DAI_CH_CDSPDIFINB1L = 0x095,
	DAI_CH_CDSPDIFINB1R = 0x09D,
	DAI_CH_CDSPDIFINC1L = 0x115,
	DAI_CH_CDSPDIFINC1R = 0x11D,
	DAI_CH_CDSPDIFIND1L = 0x195,
	DAI_CH_CDSPDIFIND1R = 0x19D,
	DAI_CH_CDSPDIFINA2L = 0x215,
	DAI_CH_CDSPDIFINA2R = 0x21D,
	DAI_CH_CDSPDIFINB2L = 0x295,
	DAI_CH_CDSPDIFINB2R = 0x29D,
	DAI_CH_CDSPDIFINC2L = 0x315,
	DAI_CH_CDSPDIFINC2R = 0x31D,
	DAI_CH_CDSPDIFIND2L = 0x395,
	DAI_CH_CDSPDIFIND2R = 0x39D,
	DAI_CH_CDSPDIFINA3L = 0x415,
	DAI_CH_CDSPDIFINA3R = 0x41D,
	DAI_CH_CDSPDIFINB3L = 0x495,
	DAI_CH_CDSPDIFINB3R = 0x49D,
	DAI_CH_CDSPDIFINC3L = 0x515,
	DAI_CH_CDSPDIFINC3R = 0x51D,
	DAI_CH_CDSPDIFIND3L = 0x595,
	DAI_CH_CDSPDIFIND3R = 0x59D,
	DAI_CH_CDSPDIFINA4L = 0x615,
	DAI_CH_CDSPDIFINA4R = 0x61D,
	DAI_CH_CDSPDIFINB4L = 0x695,
	DAI_CH_CDSPDIFINB4R = 0x69D,
	DAI_CH_CDSPDIFINC4L = 0x715,
	DAI_CH_CDSPDIFINC4R = 0x71D,
	DAI_CH_CDSPDIFIND4L = 0x795,
	DAI_CH_CDSPDIFIND4R = 0x79D,
	DAI_CH_CDSPDIFINA5L = 0x815,
	DAI_CH_CDSPDIFINA5R = 0x81D,
	DAI_CH_CDSPDIFINB5L = 0x895,
	DAI_CH_CDSPDIFINB5R = 0x89D,
	DAI_CH_CDSPDIFINC5L = 0x915,
	DAI_CH_CDSPDIFINC5R = 0x91D,
	DAI_CH_CDSPDIFIND5L = 0x995,
	DAI_CH_CDSPDIFIND5R = 0x99D,
	DAI_CH_CDSPDIFINA6L = 0xA15,
	DAI_CH_CDSPDIFINA6R = 0xA1D,
	DAI_CH_CDSPDIFINB6L = 0xA95,
	DAI_CH_CDSPDIFINB6R = 0xA9D,
	DAI_CH_CDSPDIFINC6L = 0xB15,
	DAI_CH_CDSPDIFINC6R = 0xB1D,
	DAI_CH_CDSPDIFIND6L = 0xB95,
	DAI_CH_CDSPDIFIND6R = 0xB9D,
	DAI_CH_CDSPDIFINA7L = 0xC15,
	DAI_CH_CDSPDIFINA7R = 0xC1D,
	DAI_CH_CDSPDIFINB7L = 0xC95,
	DAI_CH_CDSPDIFINB7R = 0xC9D,
	DAI_CH_CDSPDIFINC7L = 0xD15,
	DAI_CH_CDSPDIFINC7R = 0xD1D,
	DAI_CH_CDSPDIFIND7L = 0xD95,
	DAI_CH_CDSPDIFIND7R = 0xD9D,
	DAI_CH_CDSPDIFINA8L = 0xE15,
	DAI_CH_CDSPDIFINA8R = 0xE1D,
	DAI_CH_CDSPDIFINB8L = 0xE95,
	DAI_CH_CDSPDIFINB8R = 0xE9D,
	DAI_CH_CDSPDIFINC8L = 0xF15,
	DAI_CH_CDSPDIFINC8R = 0xF1D,
	DAI_CH_CDSPDIFIND8L = 0xF95,
	DAI_CH_CDSPDIFIND8R = 0xF9D
};

/* GPIO */
/* SB046x / SB067x / SB0760 */
/* GPIO out */
#define GPIO_O_RESET_DAC		(1<<1)	/* reset DAC (0=default) */
#define GPIO_O_INDRV_SPDIF_BYPASS	(1<<2)	/* 1=bypass (0=def) */
#define GPIO_O_INDRV_DAC_96K		(1<<5)	/* 0=48kHz(def), 1=96kHz */
#define GPIO_O_BACK_LINEOUT_MUTE	(1<<6)	/* 0=mute(def) */
#define GPIO_O_MIC_LINE_SELECT		(1<<7)	/* 0=line(def), 1=mic */
#define GPIO_O_DIGITAL_IO_SELECT	(1<<8)	/* 0=digital, 1=analog(def) */
/* GPIO in */
#define GPIO_I_INDRV_HP_DETECT		(1<<9)	/* 1 = headphone detected */
#define GPIO_I_FP_HP_DETECT		(1<<11)	/* 0 = headphone detected */
#define GPIO_I_LO3_DETECT		(1<<13)	/* 1 = line-out3 jack det. */
#define GPIO_I_LO2_DETECT		(1<<14)	/* 1 = line-out2 jack det. */
#define GPIO_I_LO1_DETECT		(1<<15)	/* 1 = line-out1 jack det. */

/* SB073x */
/* GPIO out */
#define GPIO_O_073X_RESET_DAC		(1<<1)	/* reset DAC (0=default) */
#define GPIO_O_073X_INDRV_SPDIF_BYPASS	(1<<2)	/* 1=bypass (0=def) */
#define GPIO_O_073X_INDRV_DAC_96K	(1<<5)	/* 0=48kHz (def), 1=96kHz */
#define GPIO_O_073X_BACK_LINEOUT_MUTE	(1<<6)	/* 0=mute(def) */
#define GPIO_O_073X_MIC_LINE_SELECT	(1<<7)	/* 0=line(def), 1=mic */
/* GPIO in */
#define GPIO_I_073X_LINE_MIC_DETECT	(1<<8)	/* 0 = jack inserted?? */
#define GPIO_I_073X_INDRV_HP_DETECT	(1<<9)	/* 1 = headphone detected */
#define GPIO_I_073X_FP_HP_DETECT	(1<<11)	/* 0 = headpohne detected */
#define GPIO_I_073X_DIGOUT_DETECT	(1<<12)	/* 1 = digital out detected */
#define GPIO_I_073X_LO3_DETECT		(1<<13)	/* 1 = line-out3 jack det. */
#define GPIO_I_073X_LO2_DETECT		(1<<14)	/* 1 = line-out2 jack det. */
#define GPIO_I_073X_LO1_DETECT		(1<<15)	/* 1 = line-out1 jack det. */

/* Vista compatible */
/* GPIO out */
#define GPIO_O_UAA_RESET_DAC		(1<<1)	/* reset DAC (0=default)*/
#define GPIO_O_UAA_BACK_LINEOUT_MUTE	(1<<6)	/* 0=mute(def) */
#define GPIO_O_UAA_MIC_LINE_SELECT	(1<<7)	/* 0=line(def), 1=mic */
/* GPIO in */
#define GPIO_I_UAA_FP_LINEIN_DETECT	(1<<0)	/* 1 = jack detected */
#define GPIO_I_UAA_LINE_MIC_DETECT	(1<<8)	/* 1 = jack inserted?? */
#define GPIO_I_UAA_FP_MIC_DETECT	(1<<9)	/* 1 = jack detected */
#define GPIO_I_UAA_FP_HP_DETECT		(1<<11)	/* 0 = headphone detected */
#define GPIO_I_UAA_LO4_DETECT		(1<<12)	/* 1 = line-out4 detected */
#define GPIO_I_UAA_LO3_DETECT		(1<<13)	/* 1 = line-out3 detected */
#define GPIO_I_UAA_LO2_DETECT		(1<<14)	/* 1 = line-out2 detected */
#define GPIO_I_UAA_LO1_DETECT		(1<<15)	/* 1 = line-out1 detected */

/* SB055x */
/* GPIO out */
#define GPIO_O_055X_ANALOG_IN_MUTE	(1<<1)	/* 0=mute(def) */
#define GPIO_O_055X_ADC_BOOST		(1<<2)	/* 0=boost off(def), 1=on */
#define GPIO_O_055X_SPDO0_MUTE		(1<<3)	/* 0=mute, 1=unmute(def) */
#define GPIO_O_055X_FP_MIC_SELECT	(1<<4)	/* 1=FP mic (0=def) */
#define GPIO_O_055X_EXDRV_DAC_96K	(1<<5)	/* 0=48kHz(def), 1=96kHz */
#define GPIO_O_055X_LINEOUT1_MUTE	(1<<6)	/* 1=mute (0=def) */
#define GPIO_O_055X_MIC_POWER_ON	(1<<7)	/* 1=power on (0=def) */
#define GPIO_O_055X_DIGITAL_IO_SEL	(1<<8)	/* 0=digital, 1=analog(def) */
#define GPIO_O_055X_MIC_SW		(1<<9)	/* 0=line/aux(def), 1=f/bmic */
#define GPIO_O_055X_AUX_MICLINE_SEL	(1<<12)	/* 0=mic/line (def=0) */
/* GPIO in */
#define GPIO_I_055X_FP_MIC_DETECT	(1<<0)	/* 1 = jack detected */
#define GPIO_I_055X_FP_HP_DETECT	(1<<11)	/* 0 = headphone detected */
#define GPIO_I_055X_LO3_DETECT		(1<<13)	/* 1 = line-out3 detected */
#define GPIO_I_055X_LO2_DETECT		(1<<14)	/* 1 = line-out2 detected */
#define GPIO_I_055X_LO1_DETECT		(1<<15)	/* 1 = line-out1 detected */

#endif /* __SOUND_EMU20K1_REGS_H */
